ChainInfo class abstract
- Implementers
- ArbitrumChain
- AuroraChain
- AvalancheChain
- BaseChain
- BSCChain
- CeloChain
- ComboChain
- ConfluxESpaceChain
- CronosChain
- EthereumChain
- FantomChain
- GnosisChain
- HarmonyChain
- HecoChain
- KccChain
- KlaytnChain
- LineaChain
- MantleChain
- MapoChain
- MetisChain
- MoonbeamChain
- MoonriverChain
- OasisEmeraldChain
- OKBCChain
- OKCChain
- OpBNBChain
- OptimismChain
- PlatONChain
- PolygonChain
- PolygonZkEVMChain
- ScrollChain
- SolanaChain
- TaikoChain
- ThunderCoreChain
- TronChain
- ZkMetaChain
- ZkSyncChain
Constructors
Properties
- chainId ↔ int
-
getter/setter pair
- chainIdName ↔ String
-
getter/setter pair
- chainName ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited