ChainName enum

Inheritance
Available extensions

Values

Solana → const ChainName
Ethereum → const ChainName
Avalanche → const ChainName
Polygon → const ChainName
Moonbeam → const ChainName
Moonriver → const ChainName
Heco → const ChainName
BSC → const ChainName
Fantom → const ChainName
Arbitrum → const ChainName
Harmony → const ChainName
Aurora → const ChainName
KCC → const ChainName
Optimism → const ChainName
PlatON → const ChainName
Tron → const ChainName
OKC → const ChainName
ThunderCore → const ChainName
Cronos → const ChainName
OasisEmerald → const ChainName
Gnosis → const ChainName
Celo → const ChainName
Klaytn → const ChainName
Scroll → const ChainName
ZkSync → const ChainName
Metis → const ChainName
ConfluxESpace → const ChainName
Mapo → const ChainName
PolygonZkEVM → const ChainName
Base → const ChainName
Linea → const ChainName
Combo → const ChainName
Mantle → const ChainName
ZkMeta → const ChainName
OpBNB → const ChainName
OKBC → const ChainName
Taiko → const ChainName

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ChainName>
A constant List of the values in this enum, in order of their declaration.