Wallet class

Annotations
  • @JsonSerializable.new()

Constructors

Wallet({required String uuid, required String chainName, required String publicAddress})
Wallet.fromJson(Map<String, dynamic> json)
factory

Properties

chainName → String
final
hashCode → int
The hash code for this object.
no setterinherited
publicAddress → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uuid → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited